﻿# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import requests
try:
    import bs4 as BeautifulSoup
except:
    import BeautifulSoup

uninstallkey = []

# Declaring specific app values (TO CHANGE)
bin_name_string = 'inkscape-%s-x86.exe'
silent_args = '/S /ALLUSER=ON /CONTEXTMENU=OFF'


def install():
    # Specific app values
    package_version = control.version.split('-')[0]

    bin_name = bin_name_string % package_version

    # Uninstalling version installed with exe instead of msi
    for uninstall in installed_softwares('inkscape'):
        if 'msiexec.exe' in str(uninstall_cmd(uninstall['key'])).lower() :
            run(uninstall_cmd(uninstall['key']))
            force = True

    # Installing the package
    install_exe_if_needed(bin_name
        ,silentflags=silent_args
        ,key='Inkscape'
        ,min_version=package_version,get_version=get_version_ink)

def get_version_ink(key):
    return key['version'].split('-')[0]



def update_package():
    print('Download/Update package content from upstream binary sources')

    # Getting proxy informations from WAPT settings
    proxy = {}
    if platform.system()=='Windows' and isfile(makepath(user_local_appdata(),'waptconsole','waptconsole.ini')):
        proxywapt = inifile_readstring(makepath(user_local_appdata(),'waptconsole','waptconsole.ini'),'global','http_proxy')
        if proxywapt :
            proxy = {'http':proxywapt,'https':proxywapt}

    # Specific app values
    app_name = control.name
    url = 'https://inkscape.org/release/?latest=1'

    # Getting latest version from official website
    page = requests.get(url,proxies=proxy).text
    bs = BeautifulSoup.BeautifulSoup(page)
    bs_raw_string = bs.find('h2',text='Revisions')
    label = bs_raw_string.findNext().findNext()
    version = label.find('label').text

    latest_bin = bin_name_string % version

    url_dl = 'https://media.inkscape.org/dl/resources/file/%s' % latest_bin

    print('Latest ' + app_name + ' version is: ' + version)
    print('Download url is: ' + url_dl)

    if len(version.split('.')) == 2:
        version = version + '.0'

    newfilename = bin_name_string % version

    # Downloading latest binaries
    if not isfile(newfilename):
        print('Downloading: ' + latest_bin)
        wget(url_dl,newfilename,proxies=proxy)

		# Change version of the package
        pe = PackageEntry().load_control_from_wapt('.')
        pe.version = '%s-%s'%(version,int(pe.version.split('-',1)[1])+1)
        pe.save_control_to_wapt('.')
        print('Changing version to ' + pe.version + ' in WAPT\\control')
        print('Update package done. You can now build-upload your package')
    else:
        print('This package is already up-to-date')

    # Deleting outdated binaries
    for bin_in_dir in glob.glob('*.exe'):
        if bin_in_dir != newfilename :
            print('Outdated binary: ' + bin_in_dir + ' Deleted')
            remove_file(bin_in_dir)
